@@ -33,6 +33,11 @@ from os_apply_config import version
 
 DEFAULT_TEMPLATES_DIR = '/usr/libexec/os-apply-config/templates'
 
+LOG_FORMAT = '[%(asctime)s] [%(levelname)s] %(message)s'
+DATE_FORMAT = '%Y/%m/%d %I:%M:%S %p'
+
+logger = logging.getLogger('os-apply-config')
+
 
 def templates_dir():
     """Determine the default templates directory path
@@ -89,7 +94,7 @@ def _extract_key(config_path, key, fallback_metadata=None):
                 raise TypeError()
         except (KeyError, TypeError):
             try:
-                if type(config) == list:
+                if isinstance(config, list):
                     config = config[int(key)]
                     continue
             except (IndexError, ValueError):
@@ -108,7 +113,7 @@ def print_key(
             return
         else:
             raise exc.ConfigException(
-                'key %s does not exist in %s' % (key, config_path))
+                'key {} does not exist in {}'.format(key, config_path))
     value_types.ensure_type(str(config), type_name)
     if isinstance(config, (dict, list, bool)):
         print(json.dumps(config))
@@ -150,7 +155,7 @@ def write_file(path, obj):
     d = os.path.dirname(path)
     os.path.exists(d) or os.makedirs(d)
     with tempfile.NamedTemporaryFile(dir=d, delete=False) as newfile:
-        if type(obj.body) == str:
+        if isinstance(obj.body, str):
             obj.body = obj.body.encode('utf-8')
         newfile.write(obj.body)
         os.chmod(newfile.name, mode)
@@ -322,19 +327,30 @@ def load_list_from_json(json_file):
     return json_obj
 
 
+def add_handler(logger, handler):
+    handler.setFormatter(logging.Formatter(LOG_FORMAT, datefmt=DATE_FORMAT))
+    logger.addHandler(handler)
+
+
 def main(argv=sys.argv):
     opts = parse_opts(argv)
     if opts.print_templates:
         print(opts.templates)
         return 0
 
+    logger.setLevel(logging.INFO)
+    add_handler(logger, logging.StreamHandler())
+    if os.geteuid() == 0:
+        add_handler(logger,
+                    logging.FileHandler('/var/log/os-apply-config.log'))
+
     if not opts.metadata:
         if 'OS_CONFIG_FILES' in os.environ:
             opts.metadata = os.environ['OS_CONFIG_FILES'].split(':')
         else:
             opts.metadata = load_list_from_json(opts.os_config_files)
-            if ((not opts.metadata and opts.os_config_files ==
-                 OS_CONFIG_FILES_PATH)):
+            if (not opts.metadata and opts.os_config_files ==
+                    OS_CONFIG_FILES_PATH):
                 logger.warning('DEPRECATED: falling back to %s' %
                                OS_CONFIG_FILES_PATH_OLD)
                 opts.metadata = load_list_from_json(OS_CONFIG_FILES_PATH_OLD)
@@ -365,23 +381,3 @@ def main(argv=sys.argv):
         logger.error(e)
         return 1
     return 0
-
-
-# logging
-LOG_FORMAT = '[%(asctime)s] [%(levelname)s] %(message)s'
-DATE_FORMAT = '%Y/%m/%d %I:%M:%S %p'
-
-
-def add_handler(logger, handler):
-    handler.setFormatter(logging.Formatter(LOG_FORMAT, datefmt=DATE_FORMAT))
-    logger.addHandler(handler)
-
-
-logger = logging.getLogger('os-apply-config')
-logger.setLevel(logging.INFO)
-add_handler(logger, logging.StreamHandler())
-if os.geteuid() == 0:
-    add_handler(logger, logging.FileHandler('/var/log/os-apply-config.log'))
-
-if __name__ == '__main__':
-    sys.exit(main(sys.argv))
